@@ -34,7 +34,7 @@ void Therver::OnClientConnected(ting::Ref<cliser::Client>& client){
 	ASSERT(client.DynamicCast<Client>().IsValid())
 	Ref<Client> c = client.StaticCast<Client>();
 
-	TRACE(<< "!!!! CLIENT CONNECTED !!!!" << std::endl)
+//	TRACE(<< "!!!! CLIENT CONNECTED !!!!" << std::endl)
 }
 
 
@@ -45,7 +45,7 @@ void Therver::OnClientDisconnected(ting::Ref<cliser::Client>& client){
 	ASSERT(client.DynamicCast<Client>().IsValid())
 	Ref<Client> c = client.StaticCast<Client>();
 	
-	TRACE(<< "!!!! CLIENT DISCONNECTED !!!!" << std::endl)
+//	TRACE(<< "!!!! CLIENT DISCONNECTED !!!!" << std::endl)
 
 	this->PushMessage(Ptr<Message>(
 			new ClientDisconnectedMessage(this, c)
@@ -62,7 +62,7 @@ void Therver::OnDataReceivedFromClient(ting::Ref<cliser::Client>& client, ting::
 	
 	ASSERT(d.Size() > 0)
 	
-	TRACE(<< "!!!! DATA RECEIVED !!!! " << d.SizeInBytes() << " bytes, d[0] = " << u32(d[0])  << std::endl)
+//	TRACE(<< "!!!! DATA RECEIVED !!!! " << d.SizeInBytes() << " bytes, d[0] = " << u32(d[0])  << std::endl)
 
 	this->PushMessage(Ptr<Message>(
 			new NetworkDataFromClientReceivedMessage(this, c, d)
