@@ -1,44 +1,33 @@
 #include <iostream>
 #include <string>
+#include <cstdlib>
 
 #include <ting/Socket.hpp>
 #include <ting/Timer.hpp>
 
 #include "Therver.hpp"
 
-#include "SQLite.hpp"
+
+using namespace ting;
 
 
 
 int main(int argc, char *argv[]) throw(){
 	try{
-
-		//TODO: remove this redundant commented code
-//		sqlite::Database db("users.db");
-
-		//db.CreateTable("users", "login TEXT, password TEXT");
-
-//		db.Delete("users", "pw = 'test'");
-//		db.Insert("users", "", "'testUser', 'test'");
-//		db.Update("users", "login = 'testUserUpdated'", "login = 'testUser'");
-//		sqlite::Cursor cur = db.Query("users", "un", "un = 'uuu'");
-
-//		TRACE(<< "cur.MoveToNext() = " << cur.MoveToNext() << std::endl)
-//		TRACE(<< "cur.GetText(un) = " << cur.GetText("un") << std::endl)
-//		TRACE(<< "cur.MoveToNext() = " << cur.MoveToNext() << std::endl)
-//		TRACE(<< "cur.MoveToNext() = " << cur.MoveToNext() << std::endl)
-
-		if(argc != 2){
+		if(argc < 2){
 			std::cout << "ERROR: need path to data directory" << std::endl;
 			return 0;
 		}
 
 		std::string dataDir;
 
-		if(argc == 2){
-			dataDir = std::string(argv[1]) + "/";
-		}else{
-			ASSERT_ALWAYS(false)
+		ASSERT(argc >= 2);
+		dataDir = std::string(argv[1]) + "/";
+
+		u16 port = 13666;
+
+		if(argc >= 3){
+			port = u16(atoi(argv[2]));
 		}
 
 		ASSERT(dataDir.size() > 0)
@@ -50,7 +39,7 @@ int main(int argc, char *argv[]) throw(){
         ting::SocketLib socketLib;
         
         {
-            Therver s(dataDir);
+            Therver s(port, dataDir);
             s.MainLoop();
         }
         
