@@ -11,13 +11,13 @@
 #include <ting/Thread.hpp>
 #include <ting/Singleton.hpp>
 #include <ting/utils.hpp>
+#include <ting/Buffer.hpp>
 
 #include <cliser/clt/NetworkThread.hpp>
 
 #include "stdafx.hpp"
 #include "MainThread.hpp"
 #include "Preferences.hpp"
-#include "ting/Buffer.hpp"
 
 
 
@@ -472,7 +472,10 @@ void ConnectRequestMessage::Handle(){
 	}
 
 	//send connect request
-	this->t->networkThread.Connect_ts(DHost(), DPort());
+	this->t->networkThread.Connect_ts(
+			Preferences::Inst().serverHost,
+			Preferences::Inst().serverPort
+		);
 
 	//change state to CONNECTING
 	this->t->ChangeNetworkState(MainThread::CONNECTING);
