@@ -40,6 +40,8 @@ OptionsDialog::OptionsDialog(Gtk::Window &parent) :
 		timbreFrame("Timbre"),
 		sinePlusADSRRadioButton("Sine + ADSR"),
 		pluckedStringRadioButton("Plucked string"),
+		tromboneRadioButton("Trombone"),
+		clarinetRadioButton("Clarinet"),
 		lockCurrentOctaveCheckbox("Lock to tapped octave")
 {
 	this->get_vbox()->add(this->hBox);
@@ -65,11 +67,17 @@ OptionsDialog::OptionsDialog(Gtk::Window &parent) :
 	{//group timbre radio buttons
 		Gtk::RadioButtonGroup gr = this->sinePlusADSRRadioButton.get_group();
 		this->pluckedStringRadioButton.set_group(gr);
+		this->tromboneRadioButton.set_group(gr);
+		this->clarinetRadioButton.set_group(gr);
 	}
 	this->timbreBox.add(this->sinePlusADSRRadioButton);
 	this->sinePlusADSRRadioButton.set_size_request(-1, DFingerFriendlyMinSize());
 	this->timbreBox.add(this->pluckedStringRadioButton);
 	this->pluckedStringRadioButton.set_size_request(-1, DFingerFriendlyMinSize());
+	this->timbreBox.add(this->tromboneRadioButton);
+	this->tromboneRadioButton.set_size_request(-1, DFingerFriendlyMinSize());
+	this->timbreBox.add(this->clarinetRadioButton);
+	this->clarinetRadioButton.set_size_request(-1, DFingerFriendlyMinSize());
 
 	this->lockCurrentOctaveCheckbox.set_size_request(-1, DFingerFriendlyMinSize());
 	this->get_vbox()->add(this->lockCurrentOctaveCheckbox);
@@ -117,6 +125,10 @@ Preferences::E_Timbre OptionsDialog::GetTimbre()const{
 		return Preferences::SINE_PLUS_ADSR;
 	else if(this->pluckedStringRadioButton.get_active())
 		return Preferences::PLUCKED_STRING;
+	else if(this->tromboneRadioButton.get_active())
+		return Preferences::TROMBONE;
+	else if(this->clarinetRadioButton.get_active())
+		return Preferences::CLARINET;
 	else
 		return Preferences::UNKNOWN;
 }
@@ -131,6 +143,12 @@ void OptionsDialog::SetTimbre(Preferences::E_Timbre timbre){
 		case Preferences::PLUCKED_STRING:
 			this->pluckedStringRadioButton.set_active(true);
 			break;
+		case Preferences::TROMBONE:
+			this->tromboneRadioButton.set_active(true);
+			break;
+		case Preferences::CLARINET:
+			this->clarinetRadioButton.set_active(true);
+			break;
 		default:
 			break;
 	}
