@@ -52,6 +52,8 @@ class OptionsDialog : public Gtk::Dialog{
 	Gtk::VBox timbreBox;
 	Gtk::RadioButton sinePlusADSRRadioButton;
 	Gtk::RadioButton pluckedStringRadioButton;
+	Gtk::RadioButton tromboneRadioButton;
+	Gtk::RadioButton clarinetRadioButton;
 
 	Gtk::CheckButton lockCurrentOctaveCheckbox;
 public:
