@@ -118,6 +118,12 @@ void PlaybackThread::Run(){
 					case 1:
 						this->instr = aumiks::PluckedStringInstrument::New();
 						break;
+					case 2:
+						this->instr = aumiks::TromboneInstrument::New();
+						break;
+					case 3:
+						this->instr = aumiks::ClarinetInstrument::New();
+						break;
 				}
 			}
 
