@@ -51,6 +51,8 @@ public:
 	Preferences(const std::string& fileName) :
 			prefsFileName(fileName),
 			
+			serverPort(0),
+			
 			numOctaves(1),
 			basePitch(12 * 4),//A4
 			lockCurrentOctave(true),
@@ -64,6 +66,14 @@ public:
 	void SaveToFile();
 
 
+	
+
+	//Non-saveable settings
+	std::string serverHost;
+	ting::u16 serverPort;
+
+
+
 
 
 	//Theremin settings
