@@ -71,49 +71,49 @@ int main(int argc, char *argv[]){
 //		)
 
 
-	TRACE(<< int(Fixed<1>(-1.5f)) << std::endl)
-	TRACE(<< int(Fixed<1>(1.13f)) << std::endl)
+//	TRACE(<< int(Fixed<1>(-1.5f)) << std::endl)
+//	TRACE(<< int(Fixed<1>(1.13f)) << std::endl)
+//
+//	TRACE(<< "0.14 % 0.1 = " << (Fixed<16>(0.14f) % Fixed<16>(0.1f)) << std::endl)
+//	TRACE(<< "-0.14 % 0.1 = " << (Fixed<16>(-0.14f) % Fixed<16>(0.1f)) << std::endl)
+//
+//	TRACE(<< "Exp(-13.0) = " << Fixed<16>(-13.0f).ExpSemiTeylor() << " exp = " << exp(-13.0f) << std::endl)
+//	TRACE(<< "Exp(-10.0) = " << Fixed<16>(-10.0f).ExpSemiTeylor() << " exp = " << exp(-10.0f) << std::endl)
+//	TRACE(<< "Exp(-0.14) = " << Fixed<16>(-0.14f).ExpSemiTeylor() << " exp = " << exp(-0.14f) << std::endl)
+//	TRACE(<< "Exp(-0.1) = " << Fixed<16>(-0.1f).ExpSemiTeylor() << " exp = " << exp(-0.1f) << std::endl)
+//	TRACE(<< "Exp(-0.099) = " << Fixed<16>(-0.099f).ExpSemiTeylor() << " exp = " << exp(-0.099f) << std::endl)
+//	TRACE(<< "Exp(-0.08) = " << Fixed<16>(-0.08f).ExpSemiTeylor() << " exp = " << exp(-0.08f) << std::endl)
+//	TRACE(<< "Exp(-0.03) = " << Fixed<16>(-0.03f).ExpSemiTeylor() << " exp = " << exp(-0.03f) << std::endl)
+//
+//	TRACE(
+//			<< "Exp(0) = " << Fixed<16>(0).ExpSemiTeylor() << " exp = " << exp(0) << std::endl
+//			<< "Exp(0.001) = " << Fixed<16>(0.001f).ExpSemiTeylor() << " exp = " << exp(0.001f) << std::endl
+//			<< "Exp(0.02) = " << Fixed<16>(0.02f).ExpSemiTeylor() << " exp = " << exp(0.02f) << std::endl
+//			<< "Exp(0.1) = " << Fixed<16>(0.1f).ExpSemiTeylor() << " exp = " << exp(0.1f) << std::endl
+//			<< "Exp(0.2) = " << Fixed<16>(0.2f).ExpSemiTeylor() << " exp = " << exp(0.2f) << std::endl
+//			<< "Exp(0.3) = " << Fixed<16>(0.3f).ExpSemiTeylor() << " exp = " << exp(0.3f) << std::endl
+//			<< "Exp(0.4) = " << Fixed<16>(0.4f).ExpSemiTeylor() << " exp = " << exp(0.4f) << std::endl
+//			<< "Exp(0.499) = " << Fixed<16>(0.499f).ExpSemiTeylor() << " exp = " << exp(0.499f) << std::endl
+//			<< "Exp(0.5) = " << Fixed<16>(0.5f).ExpSemiTeylor() << " exp = " << exp(0.5f) << std::endl
+//			<< "Exp(0.7) = " << Fixed<16>(0.7f).ExpSemiTeylor() << " exp = " << exp(0.7f) << std::endl
+//			<< "Exp(1) = " << Fixed<16>(1).ExpSemiTeylor() << " exp = " << exp(1) << std::endl
+//			<< "Exp(1.3) = " << Fixed<16>(1.3f).ExpSemiTeylor() << " exp = " << exp(1.3f) << std::endl
+//			<< "Exp(1.5) = " << Fixed<16>(1.5f).ExpSemiTeylor() << " exp = " << exp(1.5f) << std::endl
+//
+//			<< "Exp(10) = " << Fixed<16>(10).ExpSemiTeylor() << " exp = " << exp(10) << std::endl
+//			<< "Exp(19.99) = " << Fixed<16>(19.99f).ExpSemiTeylor() << " exp = " << exp(19.99f) << std::endl
+//			<< "Exp(24) = " << Fixed<16>(24).ExpSemiTeylor() << " exp = " << exp(24) << std::endl
+//		)
 
-	TRACE(<< "0.14 % 0.1 = " << (Fixed<16>(0.14f) % Fixed<16>(0.1f)) << std::endl)
-	TRACE(<< "-0.14 % 0.1 = " << (Fixed<16>(-0.14f) % Fixed<16>(0.1f)) << std::endl)
-
-	TRACE(<< "Exp(-13.0) = " << Fixed<16>(-13.0f).ExpSemiTeylor() << " exp = " << exp(-13.0f) << std::endl)
-	TRACE(<< "Exp(-10.0) = " << Fixed<16>(-10.0f).ExpSemiTeylor() << " exp = " << exp(-10.0f) << std::endl)
-	TRACE(<< "Exp(-0.14) = " << Fixed<16>(-0.14f).ExpSemiTeylor() << " exp = " << exp(-0.14f) << std::endl)
-	TRACE(<< "Exp(-0.1) = " << Fixed<16>(-0.1f).ExpSemiTeylor() << " exp = " << exp(-0.1f) << std::endl)
-	TRACE(<< "Exp(-0.099) = " << Fixed<16>(-0.099f).ExpSemiTeylor() << " exp = " << exp(-0.099f) << std::endl)
-	TRACE(<< "Exp(-0.08) = " << Fixed<16>(-0.08f).ExpSemiTeylor() << " exp = " << exp(-0.08f) << std::endl)
-	TRACE(<< "Exp(-0.03) = " << Fixed<16>(-0.03f).ExpSemiTeylor() << " exp = " << exp(-0.03f) << std::endl)
-	
-	TRACE(
-			<< "Exp(0) = " << Fixed<16>(0).ExpSemiTeylor() << " exp = " << exp(0) << std::endl
-			<< "Exp(0.001) = " << Fixed<16>(0.001f).ExpSemiTeylor() << " exp = " << exp(0.001f) << std::endl
-			<< "Exp(0.02) = " << Fixed<16>(0.02f).ExpSemiTeylor() << " exp = " << exp(0.02f) << std::endl
-			<< "Exp(0.1) = " << Fixed<16>(0.1f).ExpSemiTeylor() << " exp = " << exp(0.1f) << std::endl
-			<< "Exp(0.2) = " << Fixed<16>(0.2f).ExpSemiTeylor() << " exp = " << exp(0.2f) << std::endl
-			<< "Exp(0.3) = " << Fixed<16>(0.3f).ExpSemiTeylor() << " exp = " << exp(0.3f) << std::endl
-			<< "Exp(0.4) = " << Fixed<16>(0.4f).ExpSemiTeylor() << " exp = " << exp(0.4f) << std::endl
-			<< "Exp(0.499) = " << Fixed<16>(0.499f).ExpSemiTeylor() << " exp = " << exp(0.499f) << std::endl
-			<< "Exp(0.5) = " << Fixed<16>(0.5f).ExpSemiTeylor() << " exp = " << exp(0.5f) << std::endl
-			<< "Exp(0.7) = " << Fixed<16>(0.7f).ExpSemiTeylor() << " exp = " << exp(0.7f) << std::endl
-			<< "Exp(1) = " << Fixed<16>(1).ExpSemiTeylor() << " exp = " << exp(1) << std::endl
-			<< "Exp(1.3) = " << Fixed<16>(1.3f).ExpSemiTeylor() << " exp = " << exp(1.3f) << std::endl
-			<< "Exp(1.5) = " << Fixed<16>(1.5f).ExpSemiTeylor() << " exp = " << exp(1.5f) << std::endl
-
-			<< "Exp(10) = " << Fixed<16>(10).ExpSemiTeylor() << " exp = " << exp(10) << std::endl
-			<< "Exp(19.99) = " << Fixed<16>(19.99f).ExpSemiTeylor() << " exp = " << exp(19.99f) << std::endl
-			<< "Exp(24) = " << Fixed<16>(24).ExpSemiTeylor() << " exp = " << exp(24) << std::endl
-		)
-
-	byte e[2];
-	*reinterpret_cast<u16*>(e) = u16(0x0102);
-
-	TRACE(<<"e[2] (*" << reinterpret_cast<void*>(e) << ") = " << u32(e[0]) << " " << u32(e[1]) << std::endl)
-
-	byte b[4];
-	*reinterpret_cast<u32*>(b) = u32(0x01020304);
-
-	TRACE(<<"b[4] (*" << reinterpret_cast<void*>(b) << ") = " << u32(b[0]) << " " << u32(b[1]) << " " << u32(b[2]) << " " << u32(b[3]) << std::endl)
+//	byte e[2];
+//	*reinterpret_cast<u16*>(e) = u16(0x0102);
+//
+//	TRACE(<<"e[2] (*" << reinterpret_cast<void*>(e) << ") = " << u32(e[0]) << " " << u32(e[1]) << std::endl)
+//
+//	byte b[4];
+//	*reinterpret_cast<u32*>(b) = u32(0x01020304);
+//
+//	TRACE(<<"b[4] (*" << reinterpret_cast<void*>(b) << ") = " << u32(b[0]) << " " << u32(b[1]) << " " << u32(b[2]) << " " << u32(b[3]) << std::endl)
 
 
 	TRACE(<<"Program start"<<std::endl)
@@ -167,6 +167,19 @@ int main(int argc, char *argv[]){
 
 	//create preferences object
 	Preferences preferences("preferences.xml");
+
+	if(argc >= 2){
+		preferences.serverHost = std::string(argv[1]);
+	}else{
+		preferences.serverHost = std::string("188.120.242.144");
+	}
+
+	if(argc >= 3){
+		preferences.serverPort = atoi(argv[2]);
+	}else{
+		preferences.serverPort = 13666;
+	}
+
 	preferences.LoadFromFile();
 
 	MainThread mainThread;
